==> programy-3.8.5.tar.gz: programy-3.8.5/programy/storage/entities/link.py <==
"""
Copyright (c) 2016-2019 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""


class LinkStore(object):

    def create_link(self, primary_userid, provided_key, generated_key, expires, expired=False, retry_count=0):
        raise NotImplementedError("create_link missing from Link Store")

    def get_link(self, primary_userid):
        raise NotImplementedError("get_link missing from Link Store")

    def remove_link(self, primary_userid):
        raise NotImplementedError("remove_link missing from Link Store")

    def link_exists(self, userid, provided_key, generated_key):
        raise NotImplementedError("link_exists missing from Link Store")

    def update_link(self, link):
        raise NotImplementedError("update_link missing from Link Store")

==> programy-5.0.tar.gz: programy-5.0/programy/storage/entities/link.py <==
"""
Copyright (c) 2016-2020 Keith Sterling http://www.keithsterling.com

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
"""
from programy.storage.entities.store import Store


class LinkStore(Store):

    def __init__(self):
        Store.__init__(self)

    def create_link(self, primary_userid, provided_key, generated_key, expires, expired=False, retry_count=0):
        raise NotImplementedError("create_link missing from Link Store")  # pragma: no cover

    def get_link(self, userid):
        raise NotImplementedError("get_link missing from Link Store")  # pragma: no cover

    def remove_link(self, userid):
        raise NotImplementedError("remove_link missing from Link Store")  # pragma: no cover

    def link_exists(self, userid, provided_key, generated_key):
        raise NotImplementedError("link_exists missing from Link Store")  # pragma: no cover

    def update_link(self, link):
        raise NotImplementedError("update_link missing from Link Store")  # pragma: no cover
